@@ -20,7 +20,7 @@
 
 #include <config.h>
 
-#include <gnome.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -69,10 +69,12 @@ static const GtkActionEntry menu_entries[] =
 	{ "Preferences", GTK_STOCK_PREFERENCES, N_("Prefere_nces"), NULL,
 	  N_("Configure the application"), G_CALLBACK (cb_edit_preferences) },
 
+#if 0
 	{ "HideProcess", NULL, N_("_Hide Process"), "<control>H",
 	  N_("Hide process from list"), G_CALLBACK (cb_hide_process) },
 	{ "HiddenProcesses", NULL, N_("_Hidden Processes"), "<control>P",
 	  N_("Open the list of currently hidden processes"), G_CALLBACK (cb_show_hidden_processes) },
+#endif
 	{ "MemoryMaps", NULL, N_("_Memory Maps"), "<control>M",
 	  N_("Open the memory maps associated with a process"), G_CALLBACK (cb_show_memory_maps) },
 	{ "OpenFiles", NULL, N_("Open _Files"), "<control>F",
@@ -127,9 +129,11 @@ static const char ui_info[] =
 "      <separator />"
 "      <menuitem name=\"ViewDependenciesMenu\" action=\"ShowDependencies\" />"
 "      <separator />"
+#if 0
 "      <menuitem name=\"ViewHideProcessMenu\" action=\"HideProcess\" />"
 "      <menuitem name=\"ViewHiddenProcessesMenu\" action=\"HiddenProcesses\" />"
 "      <separator />"
+#endif
 "      <menuitem name=\"ViewMemoryMapsMenu\" action=\"MemoryMaps\" />"
 "      <menuitem name=\"ViewOpenFilesMenu\" action=\"OpenFiles\" />"
 "    </menu>"
@@ -147,8 +151,10 @@ static const char ui_info[] =
 "    <separator />"
 "    <menuitem action=\"ChangePriority\" />"
 "    <separator />"
+#if 0
 "    <menuitem action=\"HideProcess\" />"
 "    <separator />"
+#endif
 "    <menuitem action=\"MemoryMaps\" />"
 "    <menuitem action=\"OpenFiles\" />"
 "  </popup>";
@@ -668,11 +674,11 @@ create_main_window (ProcData *procdata)
 	GtkWidget *sys_box, *devices_box;
 	GtkWidget *sysinfo_box, *sysinfo_label;
 
-	app = gnome_app_new ("procman", _("System Monitor"));
+	app = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_title(GTK_WINDOW(app), _("System Monitor"));
 
 	main_box = gtk_vbox_new (FALSE, 0);
-	gnome_app_set_contents (GNOME_APP (app), main_box);
-	gtk_widget_show (main_box);
+	gtk_container_add(GTK_CONTAINER(app), main_box);
 	
 	width = procdata->config.width;
 	height = procdata->config.height;
@@ -771,7 +777,7 @@ create_main_window (ProcData *procdata)
 
 	/* create the statusbar */
 	procdata->statusbar = gtk_statusbar_new();
-	gnome_app_set_statusbar (GNOME_APP (app), procdata->statusbar);
+	gtk_box_pack_end(GTK_BOX(main_box), procdata->statusbar, FALSE, FALSE, 0);
 	procdata->tip_message_cid = gtk_statusbar_get_context_id
 		(GTK_STATUSBAR (procdata->statusbar), "tip_message");
 
@@ -780,6 +786,7 @@ create_main_window (ProcData *procdata)
 	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
 				      procdata->config.show_tree);
 
+	gtk_widget_show_all(app);
 	procdata->app = app;
 }
 
@@ -810,7 +817,9 @@ update_sensitivity(ProcData *data)
 						  "EndProcess",
 						  "KillProcess",
 						  "ChangePriority",
+#if 0
 						  "HideProcess",
+#endif
 						  "MemoryMaps",
 						  "OpenFiles" };
 
@@ -818,7 +827,10 @@ update_sensitivity(ProcData *data)
 						   "ShowAllProcesses",
 						   "ShowMyProcesses",
 						   "ShowDependencies",
-						   "HiddenProcesses" };
+#if 0
+						   "HiddenProcesses"
+#endif
+	};
 
 	size_t i;
 	gboolean processes_sensitivity, selected_sensitivity;
