@@ -1,9 +1,13 @@
 #ifndef _PROCMAN_MEMMAPS_H_
 #define _PROCMAN_MEMMAPS_H_
 
-#include <glib/gtypes.h>
+#include <glib.h>
 #include "procman.h"
 
+G_BEGIN_DECLS
+
 void 		create_memmaps_dialog (ProcData *procdata) G_GNUC_INTERNAL;
 
+G_END_DECLS
+
 #endif /* _PROCMAN_MEMMAPS_H_ */
